#define F_CPU 20000000UL


#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>


/**
In LF, we use the OLDED Xplained extension bhoard to pwm two leds at the same time. Can they do that?
*/

/*
In the pin definitions below, we have defined the PORT as well.
Everything works the same way as before, except you have to change PORTx with the PORT definition. 
Example: LED1_PORT.OUTSET = (1 << LED1);
*/


#define LED0		5		//pin


#define LED0_PORT	PORTF	//port





#define TOP_PERIOD 0x55

/*
    In this exercise, you will use PWM to control the brightness of LEDs
    Once we have PWM set up, controlling the brightness is super easy!
*/

int main(void)
{
	sei();
	
	LED0_PORT.DIRSET = (1 << LED0); //Datasheet say that we should put pins to PWM as outputs.
	
	/**
	In dataheet: "http://ww1.microchip.com/downloads/en/DeviceDoc/40002016A.pdf", section 4.1, Multiplexed signals, we see that if we want to use TCA0 with PD4 and PD5,
	 we need to use portmux to change TCA to Port F. We find that the led is at port F, and pin 5 by looking at datasheets and silk text for PCBs.
	*/
	PORTMUX.TCAROUTEA = (0x5 << 0); 
	
	TCA0.SPLIT.CTRLD |= (1 << TCA_SPLIT_SPLITM_bp); //Set splitmode to get access to WO4 and WO5
	
	TCA0.SPLIT.CTRLA |= (1 << TCA_SPLIT_ENABLE_bp) | (TCA_SPLIT_CLKSEL_DIV1_gc); //Enable the TCA and set prescaler to 1. Try different prescalers and see what happens.
	
	TCA0.SPLIT.CTRLB |= (1 << TCA_SPLIT_HCMP2EN_bp); //Enable High 2 to get output on WO5. See Figure 19-13 in functional description datasheet.
	
	TCA0.SPLIT.HPER = TOP_PERIOD; // Set period for High compare. See figures in datasheet. But this is the PWM Period.

	TCA0.SPLIT.HCMP2 = 0x00; //See figures in datasheet. This is the PWM duty cycle.
	
	
    while(1){
		
		/*Have some fun with the leds. Examples:
		  Have them fade between max and min
		  Have them fade in a pattern (Heartbeat?) 
		  Change the brightness based on buttons

		*/

		for (uint8_t i = 0; i < TOP_PERIOD; i++) {
			//TCA0.SPLIT.HCMP1 = i; from when we had 2 leds, will be back in 2022
			TCA0.SPLIT.HCMP2 = TOP_PERIOD-i;
			_delay_ms(2);
		}
		for (uint8_t i = TOP_PERIOD; i > 0;i--) {
			//TCA0.SPLIT.HCMP1 = i; from when we had 2 leds, will be back in 2022
			TCA0.SPLIT.HCMP2 = TOP_PERIOD-i;
			_delay_ms(2);
		}

	}
}


